package com.infobip.push.lib;

import android.os.Parcel;
import android.os.Parcelable;


/**
 * <p>Class that contains information about push notification object. Its instance is created in library when a notification is received.</p>
 * 
 * <p>InfobipPushNotification instance of MIME type <code>text/plain</code> contains id, mimeType, title, message, sound, vibrate, lights and additionalInfo
 * fields. Additionally, push with <code>text/html</code> MIME type will have a URL field sent via JSON.</p>
 */
public abstract class InfobipPushNotification implements Parcelable {

	//---------------------------------- FIELDS ----------------------------------//
	
	// Unique notification id used for displaying Notification object.
	protected int notificationId = -1;
	
	// Unique push identifier provided by Infobip push service.
	protected String id;
	
	// Push notification MIME type.
	protected String mimeType;

	// Push notification title.
	protected String title;
	
	// Push notification message.
	protected String message;
	
	// Push notification URL.
	protected String url;
	
	// Describes whether the sound will be played when the notification is received.
	protected boolean sound;
	
	// Describes whether the vibration will be executed when the notification is received.
	protected boolean vibrate;
	
	// Describes whether the lights will be turned on/off when notification is received.
	protected boolean lights;
	
	// Push notification additional info.
	protected String additionalInfo;
	
	// Push notification media data.
	protected String mediaData;
	
	//---------------------------------- FIELDS ----------------------------------//
	
	/**
	 * <p>Empty constructor.</p>
	 */
	public InfobipPushNotification() {
		
	}
	
	protected InfobipPushNotification(Parcel in) {
		readFromParcel(in);
	}

	@Override
	public int describeContents() {
		return 0;
	}

	@Override
	public void writeToParcel(Parcel dest, int flags) {
		dest.writeInt(notificationId);
		dest.writeString(id);
		dest.writeString(mimeType);
		dest.writeString(title);
		dest.writeString(message);
		dest.writeString(url);
		dest.writeByte((byte) (sound ? 1 : 0)); 
		dest.writeByte((byte) (vibrate ? 1 : 0)); 
		dest.writeByte((byte) (lights ? 1 : 0)); 
		dest.writeString(additionalInfo);
		dest.writeString(mediaData);	}
	
	private void readFromParcel(Parcel in) {
		this.notificationId = in.readInt();
		this.id = in.readString();
		this.mimeType = in.readString();
		this.title = in.readString();
		this.message = in.readString();
		this.url = in.readString();
		this.sound = in.readByte() != 0;
		this.vibrate = in.readByte() != 0;
		this.lights = in.readByte() != 0;
		this.additionalInfo = in.readString();
		this.mediaData = in.readString();
	}
	
}
