package com.infobip.push.lib.livegeo;

import android.app.AlarmManager;
import android.app.PendingIntent;
import android.app.Service;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.location.LocationManager;
import android.text.TextUtils;

import com.infobip.push.lib.util.LiveGeoUtil;
import com.infobip.push.lib.util.Prefs;
import com.infobip.push.lib.util.Util;

public class LiveGeoReceiver extends BroadcastReceiver {
	
	@Override
	public void onReceive(Context context, Intent intent) {		
		String action = intent.getAction();
		Prefs prefs = new Prefs(context);		
		
		if (LocationManager.PROVIDERS_CHANGED_ACTION.equals(action)) {
			
			if (TextUtils.isEmpty(prefs.getRegistrationId())) {
				return;
			}

			LocationManager lm = (LocationManager) context.getSystemService(Service.LOCATION_SERVICE);			
			if (lm.isProviderEnabled(LocationManager.NETWORK_PROVIDER)) {
				scheduleLocalAlarm(context);
			}
		}
		
		else if (LiveGeoUtil.NETWORK_ENABLED_ACTION.equals(action)) {
			
			if (TextUtils.isEmpty(prefs.getRegistrationId()) && !prefs.isLiveGeoEnabled()) {
				return;	
			}
			
			if (LiveGeoUtil.REQUEST_TYPE_ADD.equals(prefs.getLiveGeoRequestType())) {
				LiveGeoUtil.addLiveGeosToPlayServices(context);
			}
	    }
		
		else if (LiveGeoUtil.REQUEST_AREAS_ACTION.equals(action)) {
			
			if (TextUtils.isEmpty(prefs.getRegistrationId()) && !prefs.isLiveGeoEnabled()) {
				return;				
			}
			
			if (!Util.isNetworkConnected(context)) {
				LiveGeoUtil.filterExpiredGeofencesFromStorage(context, prefs);
				return;
			}
			
			LiveGeoIntentService.runIntentInService(context, intent);
		}
	}

	/**
	 * Schedules local alarm (for adding live geo areas) on this class in 15 seconds. This alarm is necessary because there is a 
	 * lag in the time that the end user clicks on "Google location services" and accepts it's usage.
	 * @param context
	 */
	private void scheduleLocalAlarm(Context context) {
		Intent locationSendingIntent = new Intent(context, LiveGeoReceiver.class);
    	locationSendingIntent.setAction(LiveGeoUtil.NETWORK_ENABLED_ACTION);
    	PendingIntent pi = PendingIntent.getBroadcast(context, 0, locationSendingIntent, 0);
		
		AlarmManager mgr = (AlarmManager) context.getSystemService(Context.ALARM_SERVICE);
    	mgr.set(AlarmManager.RTC, System.currentTimeMillis() + 15 * 1000, pi);
	}

}
