package com.infobip.push.lib.model;

import java.util.List;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import android.text.TextUtils;

import com.infobip.push.lib.util.Util;

public class RegistrationModel {

	private static final String TAG_DEVICE_ID 			= "deviceID";
	private static final String TAG_PHONE_REG_ID 		= "phoneRegistrationID";
	private static final String TAG_OS_TYPE 			= "OSType";
	private static final String TAG_USER_ID 			= "userID";
	private static final String TAG_CHANNEL_NAMES 		= "channelNames";
	private static final String TAG_ADDITIONAL 			= "additionalInfo";
	private static final String TAG_MCC 				= "mcc";
	private static final String TAG_MNC 				= "mnc";	
	private static final String TAG_OPERATOR_NAME 		= "operatorName";
	private static final String TAG_PHONE_MANUFACTURE 	= "phoneManufacture";
	private static final String TAG_PHONE_MODEL 		= "phoneModel";
	private static final String TAG_PHONE_VERSION_OS 	= "phoneVersionOS";
	private static final String TAG_TIME_ZONE_OFFSET	= "timeZoneOffset";
	private static final String TAG_PHONE_NUMBER		= "phoneNumber";
	private static final String TAG_SYSTEM_INFO			= "systemInfo";
	
	public String deviceId;
	public String phoneRegistrationId;
	public String osType = "Android";
	public String userId;
	public List<String> channelNames;
	public JSONObject additionalInfo = new JSONObject();
	public String mcc; //TODO int
	public String mnc; //TODO int
	public String operatorName;
	public String phoneManufacture 	= android.os.Build.MANUFACTURER;
	public String phoneModel 		= android.os.Build.MODEL;
	public String phoneVersionOs 	= android.os.Build.VERSION.RELEASE;
	public int timeZoneOffset;
	public String phoneNumber;
	
	@Override
	public String toString() {	
		return toJsonObject().toString();
	}
	
	public JSONObject toJsonObject() {
		JSONObject registrationModel = new JSONObject();			
		JSONArray channelNamesJson = new JSONArray();
		
		if (channelNames != null) {
			for (int i = 0; i < channelNames.size(); i++) {
				channelNamesJson.put(channelNames.toArray()[i]);
			}
		}
		
		try {
			registrationModel.put(TAG_DEVICE_ID, deviceId);
			registrationModel.put(TAG_PHONE_REG_ID, phoneRegistrationId);
			registrationModel.put(TAG_OS_TYPE, osType);
			registrationModel.put(TAG_USER_ID, userId);
			registrationModel.put(TAG_CHANNEL_NAMES, channelNamesJson);
			registrationModel.put(TAG_ADDITIONAL, additionalInfo);
			registrationModel.put(TAG_MCC, mcc);
			registrationModel.put(TAG_MNC, mnc);
			registrationModel.put(TAG_OPERATOR_NAME, operatorName);
			registrationModel.put(TAG_PHONE_MANUFACTURE, phoneManufacture);
			registrationModel.put(TAG_PHONE_MODEL, phoneModel);
			registrationModel.put(TAG_PHONE_VERSION_OS, phoneVersionOs);
			registrationModel.put(TAG_TIME_ZONE_OFFSET, timeZoneOffset);
			
			JSONObject systemInfo = new JSONObject();
			if (!TextUtils.isEmpty(phoneNumber)) {
				systemInfo.put(TAG_PHONE_NUMBER, phoneNumber);
				registrationModel.put(TAG_SYSTEM_INFO, systemInfo);
			}
		} catch (JSONException e) {
			Util.LogError(e.toString());
		}
		
		return registrationModel;
	}

}
