package com.infobip.push.lib.util;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;

import org.json.JSONArray;
import org.json.JSONException;
import org.json.JSONObject;

import android.content.Context;
import android.content.SharedPreferences;
import android.content.SharedPreferences.Editor;

import com.infobip.push.PushNotificationBuilder;
import com.infobip.push.RegistrationData;
import com.infobip.push.lib.model.RegistrationModel;
import com.infobip.push.lib.model.UnregistrationModel;

/**
 * This class contains information about the data that is saved in the shared preferences.
 * @author tjuric
 *
 */
public class Prefs {

	private SharedPreferences prefs = null;
	private Editor editor = null;

	private int applicationVersion = Integer.MIN_VALUE;
	private String applicationName = "";
	
	private String senderId = "";
	private String applicationId = "";
	private String applicationSecret = "";
	private String deviceId = "";
	private String phoneRegistrationId = "";
	private String userId = "";
	private String channels = "";
	private String additionalInfo = "";
	private String phoneNumber = "";
	private String packageName = "";
	
	private boolean quietTime;
	private int startQuietHour = PushNotificationBuilder.UNSET;
	private int startQuietMinute = PushNotificationBuilder.UNSET;
	private int endQuietHour = PushNotificationBuilder.UNSET;
	private int endQuietMinute = PushNotificationBuilder.UNSET;
	
	private boolean checkTimeZoneAutomatically;
	private int timeZoneOffset;
	private boolean timeZoneChanged;
	
	private boolean developerHandleMessage;
	private boolean locationEnabled;
	private boolean usingCustomLocationService;
	
	private int locationSendingInterval;
	private String locationLatitude;
	private String locationLongitude;
	private long locationTimeSaved;
	private long locationTimeSent;
	
	private boolean liveGeoEnabled;
	private String visitedAreaIds = "";
	private String activeAreaIds = "";
	private String liveGeoRequestType = "";
	
	private String messageId = "";
	private String tickerText;
	private int icon;
	private int sound = PushNotificationBuilder.UNSET;
	private int vibration = PushNotificationBuilder.UNSET;
	private int lights = PushNotificationBuilder.UNSET;
	
	private int soundResourceId = PushNotificationBuilder.UNSET;
	private String vibrationPattern = "";
	private int lightsColor = PushNotificationBuilder.UNSET;
	private int lightsOnMS = PushNotificationBuilder.UNSET;
	private int lightsOffMS = PushNotificationBuilder.UNSET;
	
	
	private int layoutId;
	private int titleId;
	private int textId;
	private int dateId;
	private int imageId;
	private int imageDrawableId;
	

	public Prefs(Context context) {
		this.prefs = context.getApplicationContext().getSharedPreferences("PREFS_PRIVATE", Context.MODE_PRIVATE);
		this.editor = this.prefs.edit();
	}

	private String getStringValue(String key) {
		if (this.prefs == null) {
			return "";
		}
		return this.prefs.getString(key, "");
	}

	private void setStringValue(String key, String value) {
		if (this.editor == null) {
			return;
		}
		this.editor.putString(key, value);
	}	
	
	public String getAppName() {
		return getStringValue("applicationName");
	}
	
	public void setAppName(String appName) {
		setStringValue("applicationName", appName);
	}
	
	public int getApplicationVersion() {
		if (this.prefs == null) {
			return Integer.MIN_VALUE;
		}
		applicationVersion = this.prefs.getInt("applicationVersion", Integer.MIN_VALUE);
		return applicationVersion;
	}
	
	public void setApplicationVersion(int applicationVersion) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("applicationVersion", applicationVersion);
	}

	public String getApplicationName() {
		if (this.prefs == null) {
			return "";
		}
		applicationName = this.prefs.getString("applicationName", "");
		return applicationName;
	}

	public void setApplicationName(String applicationName) {
		if (this.editor == null) {
			return;
		}
		this.editor.putString("applicationName", applicationName);
	}
	
	public String getSenderId() {
		if (this.prefs == null) {
			return "";
		}
		senderId = this.prefs.getString("senderId", "");
		return senderId;
	}

	public void setSenderId(String senderId) {
		if (this.editor == null) {
			return;
		}
		this.editor.putString("senderId", senderId);
	}

	public String getApplicationId() {
		if (this.prefs == null) {
			return "";
		}
		applicationId = this.prefs.getString("applicationId", "");
		return applicationId;
	}

	public void setApplicationId(String applicationId) {
		if (this.editor == null) {
			return;
		}
		this.editor.putString("applicationId", applicationId);
	}
	
	public String getApplicationSecret() {
		if (this.prefs == null) {
			return "";
		}
		applicationSecret = this.prefs.getString("applicationSecret", "");
		return applicationSecret;
	}

	public void setApplicationSecret(String applicationSecret) {
		if (this.editor == null) {
			return;
		}
		this.editor.putString("applicationSecret", applicationSecret);
	}

	public String getDeviceId() {
		if (this.prefs == null) {
			return "";
		}
		deviceId = this.prefs.getString("deviceId", "");
		return deviceId;
	}

	public void setDeviceId(String deviceId) {
		if (this.editor == null) {
			return;
		}
		this.editor.putString("deviceId", deviceId);
	}
	
	public String getRegistrationId() {
		if (this.prefs == null) {
			return "";
		}
		phoneRegistrationId = this.prefs.getString("registrationId", "");
		return phoneRegistrationId;
	}

	public void setRegistrationId(String registrationId) {
		if (this.editor == null) {
			return;
		}
		this.editor.putString("registrationId", registrationId);
	}
	
	public String getUserId() {
		if (this.prefs == null) {
			return "";
		}
		userId = this.prefs.getString("userId", "");
		return userId;
	}
	
	public void setUserId(String userId) {
		if (this.editor == null) {
			return;
		}
		this.editor.putString("userId", userId);
	}

	public List<String> getChannels() {
		if (this.prefs == null) {
			return null;
		}
		
		channels = this.prefs.getString("channels", "[]");
		List<String> channelList = new ArrayList<String>();
		
		try {
			JSONArray channelsJson = new JSONArray(channels);
			for (int i = 0; i < channelsJson.length(); i++) {
				channelList.add(channelsJson.opt(i).toString());
			}
		} catch (JSONException e) {
			Util.LogError("Failed to create JSON array of channels. Error: " + e.toString());
		}
		return channelList;
	}
	
	public void setChannels(List<String> channelNames) {
		if (this.editor == null) {
			return;
		}
		
		JSONArray channelsJsonArr = new JSONArray(channelNames);
		channels = channelsJsonArr.toString();
		this.editor.putString("channels", channels);
	}
	
	public JSONObject getAdditionalInfo() throws JSONException {
		if (this.prefs == null) {
			return null;
		}
		additionalInfo = this.prefs.getString("additionalInfo", "{}");
		return new JSONObject(additionalInfo);
	}
	
	public void setAdditionalInfo(JSONObject infos) {
		if (this.editor == null) {
			return;
		}
		additionalInfo = infos.toString();
		this.editor.putString("additionalInfo", additionalInfo);
	}
	
	public String getPhoneNumber() {
		if (this.prefs == null) {
			return "";
		}
		phoneNumber = this.prefs.getString("phoneNumber", "");
		return phoneNumber;
	}
	
	public void setPhoneNumber(String phoneNumber) {
		if (this.editor == null) {
			return;
		}
		this.editor.putString("phoneNumber", phoneNumber);
	}
	
	public String getPackageName() {
		if (this.prefs == null) {
			return "";
		}
		packageName = this.prefs.getString("packageName", "");
		return packageName;
	}
	
	public void setPackageName(String packageName) {
		if (this.editor == null) {
			return;
		}
		this.editor.putString("packageName", packageName);
	}
	
	public String getMessageId() {
		if (this.prefs == null) {
			return "";
		}
		messageId = this.prefs.getString("messageId", "");
		return messageId;
	}
	
	public void setMessageId(String messageId) {
		if (this.editor == null) {
			return;
		}
		this.editor.putString("messageId", messageId);
	}

	public boolean isDefaultMessageHandlingOverriden() {
		if (this.prefs == null) {
			return false;
		}
		developerHandleMessage = this.prefs.getBoolean("developerHandleMessage", false);
		return developerHandleMessage;
	}

	public void overrideDefaultMessageHandling(boolean developerHandleMessage) {
		if (this.editor == null) {
			return;
		}
		this.editor.putBoolean("developerHandleMessage", developerHandleMessage);
	}

	public int getStartQuietHour() {
		if (this.prefs == null) {
			return PushNotificationBuilder.UNSET;
		}
		startQuietHour = this.prefs.getInt("startQuietHour", PushNotificationBuilder.UNSET);
		return startQuietHour;
	}

	public void setStartQuietHour(int startQuietHour) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("startQuietHour", startQuietHour);
	}

	public int getEndQuietHour() {
		if (this.prefs == null) {
			return PushNotificationBuilder.UNSET;
		}
		endQuietHour = this.prefs.getInt("endQuietHour", PushNotificationBuilder.UNSET);
		return endQuietHour;
	}

	public void setEndQuietHour(int endQuietHour) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("endQuietHour", endQuietHour);
	}

	public boolean isQuietTime() {
		if (this.prefs == null) {
			return false;
		}
		quietTime = this.prefs.getBoolean("quietTime", false);
		return quietTime;
	}

	public void setQuietTime(boolean quietTime) {
		if (this.editor == null) {
			return;
		}
		this.editor.putBoolean("quietTime", quietTime);
	}

	public int getStartQuietMinute() {
		if (this.prefs == null) {
			return PushNotificationBuilder.UNSET;
		}
		startQuietMinute = this.prefs.getInt("startQuietMinute", PushNotificationBuilder.UNSET);
		return startQuietMinute;
	}

	public void setStartQuietMinute(int startQuietMinute) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("startQuietMinute", startQuietMinute);
	}

	public int getEndQuietMinute() {
		if (this.prefs == null) {
			return PushNotificationBuilder.UNSET;
		}
		endQuietMinute = this.prefs.getInt("endQuietMinute", PushNotificationBuilder.UNSET);
		return endQuietMinute;
	}

	public void setEndQuietMinute(int endQuietMinute) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("endQuietMinute", endQuietMinute);
	}
	
	public int getSound() {
		if (this.prefs == null) {
			return PushNotificationBuilder.UNSET;
		}
		sound = this.prefs.getInt("sound", PushNotificationBuilder.UNSET);
		return sound;
	}

	public void setSound(int sound) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("sound", sound);
	}
	
	public int getVibration() {
		if (this.prefs == null) {
			return PushNotificationBuilder.UNSET;
		}
		vibration = this.prefs.getInt("vibration", PushNotificationBuilder.UNSET);
		return vibration;
	}

	public void setVibration(int vibration) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("vibration", vibration);
	}
	
	public int getLight() {
		if (this.prefs == null) {
			return PushNotificationBuilder.UNSET;
		}
		lights = this.prefs.getInt("light", PushNotificationBuilder.UNSET);
		return lights;
	}

	public void setLight(int lights) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("light", lights);
	}
	
	public int getLightsColor() {
		if (this.prefs == null) {
			return PushNotificationBuilder.UNSET;
		}
		lightsColor = this.prefs.getInt("lightsColor", PushNotificationBuilder.UNSET);
		return lightsColor;
	}
	
	public void setLightsColor(int lightsColor) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("lightsColor", lightsColor);
	}
	
	public int getLightsOnMS() {
		if (this.prefs == null) {
			return PushNotificationBuilder.UNSET;
		}
		lightsOnMS = this.prefs.getInt("lightsOnMS", PushNotificationBuilder.UNSET);
		return lightsOnMS;
	}
	
	public void setLightsOnMS(int lightsOnMS) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("lightsOnMS", lightsOnMS);
	}
	
	public int getLightsOffMS() {
		if (this.prefs == null) {
			return PushNotificationBuilder.UNSET;
		}
		lightsOffMS = this.prefs.getInt("lightsOffMS", PushNotificationBuilder.UNSET);
		return lightsOffMS;
	}
	
	public void setLightsOffMS(int lightsOffMS) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("lightsOffMS", lightsOffMS);
	}
	
	public int getSoundResourceId() {
		if (this.prefs == null) {
			return PushNotificationBuilder.UNSET;
		}
		soundResourceId = this.prefs.getInt("soundResourceId", PushNotificationBuilder.UNSET);
		return soundResourceId;
	}

	public void setSoundResourceId(int soundResourceId) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("soundResourceId", soundResourceId);
	}
	
	public long[] getVibrationPattern() {
		if (this.prefs == null) {
			return null;
		}
		vibrationPattern = this.prefs.getString("vibrationPattern", "[]");
		
		ArrayList<Long> patternList = new ArrayList<Long>();		
		try {
			JSONArray pattern = new JSONArray(vibrationPattern);					
			for (int i = 0; i < pattern.length(); i++) {
				patternList.add(pattern.optLong(i));
			}			
		} catch (JSONException e) {
			Util.LogError("Failed to create JSON array for vibration pattern. Error: " + e.toString());
		}
		
		long[] patternArray = new long[patternList.size()];
		for (int i = 0; i < patternList.size(); i++) {
			patternArray[i] = patternList.get(i);
		}
		
		return patternArray;
	}

	public void setVibrationPattern(long[] vibrationPatternLong) {
		if (this.editor == null) {
			return;
		}
		
		JSONArray vibrationPatternJson = new JSONArray();
		for (long pattern : vibrationPatternLong) {
			vibrationPatternJson.put(pattern);
		}
		
		vibrationPattern = vibrationPatternJson.toString();
		this.editor.putString("vibrationPattern", vibrationPattern);
	}
	
	public String getTickerText() {
		if (this.prefs == null) {
			return "";
		}
		tickerText = this.prefs.getString("tickerText", "");
		return tickerText;
	}
	
	public void setTickerText(String tickerText) {
		if (this.editor == null) {
			return;
		}
		this.editor.putString("tickerText", tickerText);
	}

	public int getIconDrawableId() {
		if (this.prefs == null) {
			return PushNotificationBuilder.UNSET;
		}
		icon = this.prefs.getInt("icon", PushNotificationBuilder.UNSET);
		return icon;
	}

	public void setIcon(int icon) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("icon", icon);
	}

	public int getLayoutId() {
		if (this.prefs == null) {
			return PushNotificationBuilder.UNSET;
		}
		layoutId = this.prefs.getInt("layoutId", PushNotificationBuilder.UNSET);
		return layoutId;
	}

	public void setLayoutId(int layoutId) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("layoutId", layoutId);
	}

	public int getTitleId() {
		if (this.prefs == null) {
			return PushNotificationBuilder.UNSET;
		}
		titleId = this.prefs.getInt("titleId", PushNotificationBuilder.UNSET);
		return titleId;
	}

	public void setTitleId(int titleId) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("titleId", titleId);
	}

	public int getTextId() {
		if (this.prefs == null) {
			return PushNotificationBuilder.UNSET;
		}
		textId = this.prefs.getInt("remoteMessageId", PushNotificationBuilder.UNSET);
		return textId;
	}

	public void setTextId(int remoteMessageId) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("remoteMessageId", remoteMessageId);
	}
	
	public int getDateId() {
		if (this.prefs == null) {
			return PushNotificationBuilder.UNSET;
		}
		dateId = this.prefs.getInt("dateId", PushNotificationBuilder.UNSET);
		return dateId;
	}
	
	public void setDateId(int dateId) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("dateId", dateId);
	}

	public int getImageId() {
		if (this.prefs == null) {
			return PushNotificationBuilder.UNSET;
		}
		imageId = this.prefs.getInt("imageId", PushNotificationBuilder.UNSET);
		return imageId;
	}

	public void setImageId(int imageId) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("imageId", imageId);
	}

	public int getImageDrawableId() {
		if (this.prefs == null) {
			return PushNotificationBuilder.UNSET;
		}
		imageDrawableId = this.prefs.getInt("image", PushNotificationBuilder.UNSET);
		return imageDrawableId;
	}

	public void setImageDrawableId(int image) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("image", image);
	}

	public void registrationDataToPrefs(RegistrationData registrationData) {
		JSONObject additionalInfoJson = new JSONObject(registrationData.getAdditionalInfo());
		
		setPhoneNumber(registrationData.getPhoneNumber());
		setUserId(registrationData.getUserId());
		setChannels(registrationData.getChannels());
		setAdditionalInfo(additionalInfoJson);
		save();
	}

	public RegistrationModel prefsToRegistrationModel() throws JSONException {
		RegistrationModel model = new RegistrationModel();
		model.deviceId = getDeviceId();
		model.phoneRegistrationId = getRegistrationId();
		model.userId = getUserId();
		model.channelNames = getChannels();
		model.additionalInfo = getAdditionalInfo();
		model.timeZoneOffset = getTimeZoneOffset();
		model.phoneNumber = getPhoneNumber();
		return model;
	}
	
	public UnregistrationModel prefsToUnregistrationModel() {
		UnregistrationModel model = new UnregistrationModel();
		model.deviceId = getDeviceId();
		return model;
	}

	public RegistrationData prefsToUserRelatedData() {
		RegistrationData data = new RegistrationData();
		data.setPhoneNumber(getPhoneNumber());
		data.setChannels(getChannels());
		data.setUserId(getUserId());
		return data;
	}
	
	public void removeUserRelatedData() {
		if (this.editor == null) {
			return;
		}
		
		editor.remove("phoneNumber");
		editor.remove("userId");
		editor.remove("channels");
		editor.remove("additionalInfo");
		save();
	}
	
	public void removeRegistrationId() {
		if (this.editor == null) {
			return;
		}
		
		editor.remove("registrationId");
		save();
	}
	
	public void removeNotificationBuilderData(){
		if (this.editor == null) {
			return;
		}
		
		editor.remove("icon");
		editor.remove("tickerText");
		editor.remove("sound");
		editor.remove("vibration");
		editor.remove("light");
		editor.remove("layoutId");
		editor.remove("titleId");
		editor.remove("textId");
		editor.remove("dateId");
		editor.remove("imageId");
		editor.remove("image");		
		editor.remove("soundResourceId");
		editor.remove("vibrationPattern");
		save();
	}
	
	public void save() {
		if (this.editor == null) {
			return;
		}
		this.editor.commit();
	}

	public boolean isLocationEnabled() {
		locationEnabled = this.prefs.getBoolean("locationEnabled", false);
		return locationEnabled;
	}

	public void setLocationEnabled(boolean locationEnabled) {
		if (this.editor == null) {
			return;
		}
		this.editor.putBoolean("locationEnabled", locationEnabled);
	}

	public int getLocationUpdateTimeInterval() {
		if (this.prefs == null) {
			return Consts.DEFAULT_LOCATION_UPDATE_INTERVAL_MINUTES;
		}
		locationSendingInterval = this.prefs.getInt("locationSendingInterval", Consts.DEFAULT_LOCATION_UPDATE_INTERVAL_MINUTES);		
		return locationSendingInterval;
	}
	
	public void setLocationUpdateTimeInterval(int locationSendingInterval) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("locationSendingInterval", locationSendingInterval);
	}

	public boolean isUsingCustomLocationService() {
		if (this.prefs == null) {
			return false;
		}
		usingCustomLocationService = this.prefs.getBoolean("usingCustomLocationService", false);
		return usingCustomLocationService;
	}

	public void setUsingCustomLocationService(boolean usingCustomLocationService) {
		if (this.editor == null) {
			return;
		}
		this.editor.putBoolean("usingCustomLocationService", usingCustomLocationService);
	}

	public String getLocationLatitude() {
		if (this.prefs == null) {
			return "0";
		}
		locationLatitude = this.prefs.getString("locationLatitude", "0");
		return locationLatitude;
	}

	public void setLocationLatitude(String locationLatitude) {
		if (this.editor == null) {
			return;
		}
		this.editor.putString("locationLatitude", locationLatitude);
	}

	public String getLocationLongitude() {
		if (this.prefs == null) {
			return "0";
		}
		locationLongitude = this.prefs.getString("locationLongitude", "0");
		return locationLongitude;
	}

	public void setLocationLongitude(String locationLongitude) {
		if (this.editor == null) {
			return;
		}
		this.editor.putString("locationLongitude", locationLongitude);
	}
	
	public boolean isLiveGeoEnabled() {
		liveGeoEnabled = this.prefs.getBoolean("liveGeoEnabled", false);
		return liveGeoEnabled;
	}
	
	public void setLiveGeoEnabled(boolean liveGeoEnabled) {
		if (this.editor == null) {
			return;
		}
		this.editor.putBoolean("liveGeoEnabled", liveGeoEnabled);
	}
	
	public List<String> getVisitedAreaIds() {
		if (this.prefs == null) {
			return null;
		}
		
		visitedAreaIds = this.prefs.getString("visitedAreaIds", "[]");
		List<String> visitedAreaIdsList = new ArrayList<String>();
		
		try {
			JSONArray visitedAreasJson = new JSONArray(visitedAreaIds);
			for (int i = 0; i < visitedAreasJson.length(); i++) {
				visitedAreaIdsList.add(visitedAreasJson.opt(i).toString());
			}
		} catch (JSONException e) {
			Util.LogError("Failed to create JSON array of visitedAreaIds. Error: " + e.toString());
		}
		return visitedAreaIdsList;
	}
	
	public void setVisitedAreaIds(List<String> visitedAreaIdsList) {
		if (this.editor == null) {
			return;
		}
		
		JSONArray visitedAreasJsonArr = new JSONArray(visitedAreaIdsList);
		visitedAreaIds = visitedAreasJsonArr.toString();
		this.editor.putString("visitedAreaIds", visitedAreaIds);
	}
	
	public void removeFromVisitedAreaIds(List<String> visitedAreaIdsList) {
		if (this.editor == null) {
			return;
		}
		
		List<String> visitedAreaIds = getVisitedAreaIds();
		visitedAreaIds.removeAll(visitedAreaIdsList);
		setVisitedAreaIds(visitedAreaIds); 
	}
	
	public void appendVisitedAreaIds(HashSet<String> visitedAreaIdsSet) {
		if (this.editor == null) {
			return;
		}
		
		visitedAreaIdsSet.addAll(getVisitedAreaIds());
		
		JSONArray visitedAreasJsonArr = new JSONArray(visitedAreaIdsSet);
		visitedAreaIds = visitedAreasJsonArr.toString();
		this.editor.putString("visitedAreaIds", visitedAreaIds);
	}
	
	public void removeAllVisitedAreaIds() {
		if (this.editor == null) {
			return;
		}
		
		editor.remove(visitedAreaIds);
		save();
	}
	
	public List<String> getActiveAreaIds() {
		if (this.prefs == null) {
			return null;
		}
		
		activeAreaIds = this.prefs.getString("activeAreaIds", "[]");
		List<String> activeAreaIdsList = new ArrayList<String>();
		
		try {
			JSONArray activeAreaIdsJson = new JSONArray(activeAreaIds);
			for (int i = 0; i < activeAreaIdsJson.length(); i++) {
				activeAreaIdsList.add(activeAreaIdsJson.opt(i).toString());
			}
		} catch (JSONException e) {
			Util.LogError("Failed to create JSON array of activeAreaIds. Error: " + e.toString());
		}
		return activeAreaIdsList;
	}
	
	public void setActiveAreaIds(List<String> activeAreaIdsList) {
		if (this.editor == null) {
			return;
		}
		
		JSONArray activeAreasJsonArr = new JSONArray(activeAreaIdsList);
		activeAreaIds = activeAreasJsonArr.toString();
		this.editor.putString("activeAreaIds", activeAreaIds);
	}
	
	public void removeFromActiveAreaIds(List<String> activeAreaIdsList) {
		if (this.editor == null) {
			return;
		}
		
		List<String> activeAreaIds = getActiveAreaIds();
		activeAreaIds.removeAll(activeAreaIdsList);
		setActiveAreaIds(activeAreaIds); 
	}
	
	public void appendActiveAreaIds(HashSet<String> activeAreaIdsSet) {
		if (this.editor == null) {
			return;
		}
		
		activeAreaIdsSet.addAll(getActiveAreaIds());
		
		JSONArray activeAreasJsonArr = new JSONArray(activeAreaIdsSet);
		activeAreaIds = activeAreasJsonArr.toString();
		this.editor.putString("activeAreaIds", activeAreaIds);
	}
	
	public void appendActiveAreaIds(String activeAreaId) {
		if (this.editor == null) {
			return;
		}
		
		List<String> activeAreaIdsSet = getActiveAreaIds();
		activeAreaIdsSet.add(activeAreaId);
		
		JSONArray activeAreasJsonArr = new JSONArray(activeAreaIdsSet);
		activeAreaIds = activeAreasJsonArr.toString();
		this.editor.putString("activeAreaIds", activeAreaIds);
	}
	
	public void removeAllActiveAreaIds() {
		if (this.editor == null) {
			return;
		}

		editor.remove("activeAreaIds");
		save();
	}
	
	public String getLiveGeoRequestType() {
		if (this.prefs == null) {
			return null;
		}
		
		liveGeoRequestType = this.prefs.getString("liveGeoRequestType", "");
		return liveGeoRequestType;
	}
	
	public void setLiveGeoRequestType(String liveGeoRequestType) {
		if (this.editor == null) {
			return;
		}
		this.editor.putString("liveGeoRequestType", liveGeoRequestType);
	}

	public long getLocationTimeSaved() {
		if (this.prefs == null) {
			return 0;
		}
		locationTimeSaved = this.prefs.getLong("locationTimeSaved", 0);
		return locationTimeSaved;
	}

	public void setLocationTimeSaved(long locationTimeSaved) {
		if (this.editor == null) {
			return;
		}
		this.editor.putLong("locationTimeSaved", locationTimeSaved);
	}
	
	public long getLocationTimeSent() {
		if (this.prefs == null) {
			return 0;
		}
		locationTimeSent = this.prefs.getLong("locationTimeSent", 0);
		return locationTimeSent;
	}
	
	public void setLocationTimeSent(long locationTimeSent) {
		if (this.editor == null) {
			return;
		}
		this.editor.putLong("locationTimeSent", locationTimeSent);
	}

	public int getTimeZoneOffset() {
		if (this.prefs == null) {
			return Consts.TIME_ZONE_OFFSET_UNSET;
		}
		timeZoneOffset = this.prefs.getInt("timeZoneOffset", Consts.TIME_ZONE_OFFSET_UNSET);
		return timeZoneOffset;
	}

	public void setTimeZoneOffset(int timeZoneOffset) {
		if (this.editor == null) {
			return;
		}
		this.editor.putInt("timeZoneOffset", timeZoneOffset);
	}

	public boolean isCheckingTimeZoneAutomatically() {
		checkTimeZoneAutomatically = this.prefs.getBoolean("checkTimeZoneAutomatically", true);
		return checkTimeZoneAutomatically;
	}

	public void setCheckTimeZoneAutomatically(boolean checkTimeZoneAutomatically) {
		if (this.editor == null) {
			return;
		}
		this.editor.putBoolean("checkTimeZoneAutomatically", checkTimeZoneAutomatically);
	}
	
	public boolean isTimeZoneChanged() {
		timeZoneChanged = this.prefs.getBoolean("timeZoneChanged", false);
		return timeZoneChanged;
	}
	
	public void setTimeZoneChanged(boolean timeZoneChanged) {
		if (this.editor == null) {
			return;
		}
		this.editor.putBoolean("timeZoneChanged", timeZoneChanged);
	}
	
}
